# django-viewwork

[![GitHub Actions](https://github.com/pikhovkin/django-viewwork/workflows/build/badge.svg)](https://github.com/pikhovkin/django-viewwork/actions)
[![PyPI](https://img.shields.io/pypi/v/django-viewwork.svg)](https://pypi.org/project/django-viewwork/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-viewwork.svg)
[![framework - Django](https://img.shields.io/badge/framework-Django-0C3C26.svg)](https://www.djangoproject.com/)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-viewwork.svg)
[![PyPI - License](https://img.shields.io/pypi/l/django-viewwork)](./LICENSE)

Auto-collection of views, auto-generation of urls and easy menu creation

### Installation

```bash
$ pip install django-viewwork
```

Install with `django-easy-select2`
```bash
$ pip install django-viewwork[select2]
```

### Usage

```python

```

### License

MIT
